@@ -5,6 +5,8 @@ from openpyxl import \
     Workbook, \
     load_workbook
 
+from domain.distribution.distribution_data import DistributionData
+from domain.distribution.distribution_sheet import DistributionSheet
 from xlsx_lib.domain.power_supply.power_supply_component import PowerSupplyComponent
 from xlsx_lib.domain.power_supply.power_supply_sheet import PowerSupplySheet
 from xlsx_lib.domain.frame.frame_element import FrameElement
@@ -31,11 +33,13 @@ sheetnames_relationships = {
     "PARES APRIETE": Sheetnames.TIGHTENING_TORQUES,
     "CHAS": Sheetnames.FRAME,
     "ALIM": Sheetnames.POWER_SUPPLY,
+    "DISTRIBUCION": Sheetnames.DISTRIBUTION,
 }
 
 
 class MotorcycleModelWorkbook:
     motorcycle_model: Optional[MotorcycleModel]
+    distribution_sheet_images: Optional[List[BytesIO]]
 
     def __init__(
             self,
@@ -55,6 +59,7 @@ class MotorcycleModelWorkbook:
         engine_sections: Optional[List[EngineSection]] = None
         frame_elements: Optional[List[FrameElement]] = None
         power_supply_components: Optional[List[PowerSupplyComponent]] = None
+        distribution: Optional[DistributionData] = None
 
         for sheetname in [key for key in workbook.sheetnames
                           if key in sheetnames_relationships]:
@@ -81,6 +86,12 @@ class MotorcycleModelWorkbook:
             elif Sheetnames.POWER_SUPPLY == sheetnames_relationships[sheetname]:
                 power_supply_components = PowerSupplySheet(worksheet=workbook[sheetname]).components
 
+            elif Sheetnames.DISTRIBUTION == sheetnames_relationships[sheetname]:
+                distribution_sheet: DistributionSheet = DistributionSheet(worksheet=workbook[sheetname])
+
+                distribution = distribution_sheet.distribution_data
+                self.distribution_images = distribution_sheet.distribution_images
+
         self.motorcycle_model = MotorcycleModel(
             model_name=model_name,
             generic_replacements=generic_replacements,
@@ -89,5 +100,5 @@ class MotorcycleModelWorkbook:
             engine=engine_sections,
             frame=frame_elements,
             power_supply=power_supply_components,
+            distribution=distribution,
         )
-
